@@ -496,7 +496,7 @@ class typeFile():
     def getMTypeBuf_(self, buf):
         try:
             ret = self.magicObject.buffer(buf).decode('utf-8')
-        except UnicodeDecodeError:
+        except (UnicodeDecodeError, AttributeError):
             ret = self.magicObject.buffer(buf)
             return None
         return ret
@@ -543,7 +543,7 @@ class typeFile():
         except UnicodeDecodeError:
             try:
                 return self.magicObject.file(filename.decode('utf-8'))
-            except UnicodeDecodeError:
+            except (UnicodeDecodeError, AttributeError):
                 return None
         # fix for kernel 3.7.7 (bad work samba)
         if ret is None and self.magicObject.errno() == 5:
