@@ -160,6 +160,12 @@ class VariableClPassFile(Variable):
     """
 
 
+class VariableClPassPath(Variable):
+    """
+    Full path to current template
+    """
+
+
 class VariableClPassLocation(Variable):
     """
     Текущая обрабатываемая локация
